gregstoll

Joined 18 years ago

Karma
208
Submissions
67
Member since
Mar 4
My homepage is https://gregstoll.com - I have a bunch of random side projects there.
View on Hacker News

Recent submissions

Comment · 5 months ago
Nope, our standards position on that is still negative, for one thing.
Comment · 5 months ago
Hopefully it will just work, if not please file a bug! I tested with a variety of hardware and sites but of course I couldn't try everything...
Comment · 5 months ago
Yup! Arduino is one of the things I tested with. (I worked on this for Mozilla)
Comment · 5 months ago
Comment · 5 months ago
As others have said, you'll get a dialog if any site actually tries to use this. But if you want to fully turn it off, just set "dom.webserial.enabled" to false in about:config (and restart Firefox)
Comment · 9 months ago
Comment · 2 years ago
Comment · 4 years ago
To be fair the blog posts have original intros that often give more context about what prompted him to write about that topic at that time.
Comment · 4 years ago
Comment · 4 years ago
I'm guessing like Mt. Gox, the former bitcoin exchange that halted trading and eventually shut down.
Comment · 5 years ago
Thanks! Just gave this a try and it didn't seem to help, but I'll remember for next time :-)
Comment · 5 years ago
Yup, that makes a lot of sense - I didn't realize Python cached so many previous regex's, which is nice!

I did use cprofile a while back and I think at the time it showed a lot of time in the regexp matching. (I don't think I posted about it though) Honestly, once I implemented the parallelism I got less motivated to make it faster. But now I am kinda curious what the speed difference is between Rust and Python if I spend time trying to optimize both.

Thanks for the suggestions!

Comment · 5 years ago
OP here. I went ahead and tried using the slicing instead of startswith() a few places, and moving the regexes out to module variables. (thanks for the suggestions!) It did speed up, but just a little bit (from ~32 secs to ~31 secs).

I may try changing the "not doneParsingEvent" checks into something that uses "continue", I'd imagine that would probably help. (although the Rust code is structured the same way) Another thing I've considered is looking at the data and figuring out which cases are more common and checking for those first...

Another thing I considered is

Comment · 7 years ago
Yes - with Android Pie and above you can add a "Lockdown" option to your Restart/Shutdown menu, see https://android.gadgethacks.com/how-to/quickly-disable-finge...

You can also just restart the phone - at least on mine you can't login for the first time after a restart with a fingerprint.

Live from the official Hacker News API

A modern reader for Hacker News · SvelteKit + Skeleton